@@ -26,7 +26,7 @@ Group::Group(std::shared_ptr<AppInfo> appInfo, bool pinned) : mGroupMenu(this)
 			uint count = 0;
 			
 			mWindows.findIf([&count](GroupWindow* e) -> bool {
-				if (!e->getState(WNCK_WINDOW_STATE_SKIP_TASKLIST))
+				if (!e->getState(XFW_WINDOW_STATE_SKIP_TASKLIST))
 					++count;
 			return false;
 		
@@ -174,7 +174,7 @@ Group::Group(std::shared_ptr<AppInfo> appInfo, bool pinned) : mGroupMenu(this)
 		}),
 		this);
 
-	g_signal_connect(G_OBJECT(mButton), "draw",
+	g_signal_connect_after(G_OBJECT(mButton), "draw",
 		G_CALLBACK(+[](GtkWidget* widget, cairo_t* cr, Group* me) {
 			me->onDraw(cr);
 			return false;
@@ -224,7 +224,7 @@ void Group::add(GroupWindow* window)
 	if (mWindowsCount == 1 && !mPinned)
 		gtk_box_reorder_child(GTK_BOX(Dock::mBox), mButton, -1);
 
-	if (!mActive && wnck_window_is_active(window->mWnckWindow))
+	if (!mActive && xfw_window_is_active(window->mXfwWindow))
 		onWindowActivate(window);
 
 	gtk_widget_queue_draw(mButton);
@@ -280,8 +280,8 @@ void Group::scrollWindows(guint32 timestamp, GdkScrollDirection direction)
 void Group::closeAll()
 {
 	mWindows.forEach([](GroupWindow* w) -> void {
-		if (!w->getState(WNCK_WINDOW_STATE_SKIP_TASKLIST))
-			Wnck::close(w, 0);
+		if (!w->getState(XFW_WINDOW_STATE_SKIP_TASKLIST))
+			Xfw::close(w, 0);
 	});
 }
 
@@ -289,7 +289,11 @@ void Group::resize()
 {
 	// TODO: set `min-width` / `min-height` CSS property on button?
 	// https://github.com/davekeogh/xfce4-docklike-plugin/issues/39
-	
+
+	// may not yet be initialized
+	if (Dock::mIconSize == 0)
+		return;
+
 	if (mIconPixbuf != nullptr)
 	{
 		gint scale_factor = gtk_widget_get_scale_factor(mButton);
@@ -297,7 +301,7 @@ void Group::resize()
 		GdkPixbuf* scaled = gdk_pixbuf_scale_simple(mIconPixbuf, size, size, GDK_INTERP_BILINEAR);
 		cairo_surface_t* surface = gdk_cairo_surface_create_from_pixbuf(scaled, scale_factor, NULL);
 		gtk_image_set_from_surface(GTK_IMAGE(mImage), surface);
-		cairo_surface_destroy (surface);
+		cairo_surface_destroy(surface);
 		g_object_unref(scaled);
 	}
 	else
@@ -373,7 +377,7 @@ void Group::onDraw(cairo_t* cr)
 				orientation = ORIENTATION_BOTTOM;
 		}
 	}
-	
+
 	int indicator_style = Settings::inactiveIndicatorStyle;
 	if (mActive)
 		indicator_style = Settings::indicatorStyle;
@@ -441,17 +445,21 @@ void Group::onDraw(cairo_t* cr)
 	{
 		if (mWindowsCount > 0)
 		{
-		    int offset;
+			int offset;
 			cairo_set_source_rgba(cr, rgba[0], rgba[1], rgba[2], rgba[3]);
-			
+
 			offset = 0;
-			
-			if (mWindowsCount > 1) {
-			    if (orientation == ORIENTATION_BOTTOM || orientation == ORIENTATION_TOP) {
-			        offset = 2 * (round(h * (1 - BAR_WEIGHT)));
-			    } else {
-			        offset = (2 * (round(w * (1 - BAR_WEIGHT))));
-			    }
+
+			if (mWindowsCount > 1)
+			{
+				if (orientation == ORIENTATION_BOTTOM || orientation == ORIENTATION_TOP)
+				{
+					offset = 2 * (round(h * (1 - BAR_WEIGHT)));
+				}
+				else
+				{
+					offset = (2 * (round(w * (1 - BAR_WEIGHT))));
+				}
 			}
 
 			if (orientation == ORIENTATION_BOTTOM)
@@ -468,16 +476,18 @@ void Group::onDraw(cairo_t* cr)
 
 		if (mWindowsCount > 1)
 		{
-		    int size;
+			int size;
 			cairo_set_source_rgba(cr, rgba[0], rgba[1], rgba[2], rgba[3]);
-			
-			if (orientation == ORIENTATION_BOTTOM || orientation == ORIENTATION_TOP) {
-			    size = round(h * (1 - BAR_WEIGHT));
-			} else {
-			    size = round(w * (1 - BAR_WEIGHT));
+
+			if (orientation == ORIENTATION_BOTTOM || orientation == ORIENTATION_TOP)
+			{
+				size = round(h * (1 - BAR_WEIGHT));
 			}
-			
-			
+			else
+			{
+				size = round(w * (1 - BAR_WEIGHT));
+			}
+
 			if (orientation == ORIENTATION_BOTTOM)
 				cairo_rectangle(cr, w - size, round(h * BAR_WEIGHT), size, size);
 			else if (orientation == ORIENTATION_RIGHT)
@@ -796,11 +806,11 @@ void Group::electNewTopWindow()
 		if (mWindows.size() == 1)
 			newTopWindow = mWindows.get(0);
 		else
-			newTopWindow = Wnck::mGroupWindows.findIf([this](std::pair<gulong, std::shared_ptr<GroupWindow>> e) -> bool {
+			newTopWindow = (Xfw::mGroupWindows.findIf([this](std::pair<XfwWindow*, std::shared_ptr<GroupWindow>> e) -> bool {
 				if (e.second->mGroup == this)
 					return true;
 				return false;
-			}).get();
+			})).get();
 
 		setTopWindow(newTopWindow);
 	}
@@ -828,7 +838,7 @@ void Group::onButtonPress(GdkEventButton* event)
 {
 	if (event->button == GDK_BUTTON_SECONDARY)
 	{
-		std::shared_ptr<GroupWindow> win = Wnck::mGroupWindows.findIf([this](std::pair<gulong, std::shared_ptr<GroupWindow>> e) -> bool {
+		std::shared_ptr<GroupWindow> win = Xfw::mGroupWindows.findIf([this](std::pair<XfwWindow*, std::shared_ptr<GroupWindow>> e) -> bool {
 			return (e.second->mGroupAssociated && e.second->mGroup == this);
 		});
 
@@ -837,7 +847,7 @@ void Group::onButtonPress(GdkEventButton* event)
 
 		if (mButton != nullptr)
 		{
-			GtkWidget* menu = GTK_WIDGET(g_object_ref_sink(Wnck::buildActionMenu(win.get(), this)));
+			GtkWidget* menu = GTK_WIDGET(g_object_ref_sink(Xfw::buildActionMenu(win.get(), this)));
 			xfce_panel_plugin_register_menu(Plugin::mXfPlugin, GTK_MENU(menu));
 			g_signal_connect(menu, "deactivate", G_CALLBACK(g_object_unref), nullptr);
 			gtk_menu_popup_at_widget(GTK_MENU(menu), mButton, GDK_GRAVITY_SOUTH_WEST, GDK_GRAVITY_NORTH_WEST, (GdkEvent*)event);
@@ -851,22 +861,22 @@ void Group::onButtonRelease(GdkEventButton* event)
 {
 	if (event->button == GDK_BUTTON_MIDDLE)
 	{
-		switch(Settings::middleButtonBehavior)
+		switch (Settings::middleButtonBehavior)
 		{
-			case BEHAVIOR_CLOSE_ALL:
-			{
-				closeAll();
-				break;
-			}
-			case BEHAVIOR_LAUNCH_NEW:
-			{
-				mAppInfo->launch();
-				break;
-			}
-			case BEHAVIOR_DO_NOTHING:
-			{
-				break;
-			}
+		case BEHAVIOR_CLOSE_ALL:
+		{
+			closeAll();
+			break;
+		}
+		case BEHAVIOR_LAUNCH_NEW:
+		{
+			mAppInfo->launch();
+			break;
+		}
+		case BEHAVIOR_DO_NOTHING:
+		{
+			break;
+		}
 		}
 	}
 	else if (event->state & GDK_SHIFT_MASK || (mPinned && !mWindowsCount))
@@ -927,7 +937,7 @@ void Group::onDragDataGet(const GdkDragContext* context, GtkSelectionData* selec
 
 void Group::onDragDataReceived(const GdkDragContext* context, int x, int y, const GtkSelectionData* selectionData, guint info, guint time)
 {
-	Dock::moveButton((Group*)gtk_selection_data_get_data(selectionData), this);
+	Dock::moveButton((Group*)(gpointer)gtk_selection_data_get_data(selectionData), this);
 }
 
 void Group::onDragBegin(GdkDragContext* context)
@@ -942,12 +952,12 @@ void Group::onDragBegin(GdkDragContext* context)
 		GdkPixbuf* scaled = gdk_pixbuf_scale_simple(mIconPixbuf, size, size, GDK_INTERP_BILINEAR);
 		cairo_surface_t* surface = gdk_cairo_surface_create_from_pixbuf(scaled, scale_factor, NULL);
 		gtk_drag_set_icon_surface(context, surface);
-		cairo_surface_destroy (surface);
+		cairo_surface_destroy(surface);
 		g_object_unref(scaled);
 	}
 	else
 	{
-		const gchar *icon_name;
+		const gchar* icon_name;
 		gtk_image_get_icon_name(GTK_IMAGE(mImage), &icon_name, nullptr);
 		gtk_drag_set_icon_name(context, icon_name, 0, 0);
 	}
