@@ -8,19 +8,19 @@
 #ifndef GROUP_MENU_ITEM_HPP
 #define GROUP_MENU_ITEM_HPP
 
+#include "GroupWindow.hpp"
+#include "Helpers.hpp"
+#include "Xfw.hpp"
+
 #include <gtk/gtk.h>
 
 #include <iostream>
 
-#include "GroupWindow.hpp"
-#include "Helpers.hpp"
-#include "Wnck.hpp"
-
 class GroupWindow;
 
 class GroupMenuItem
 {
-  public:
+public:
 	GroupMenuItem(GroupWindow* groupWindow);
 	~GroupMenuItem();
 
