@@ -8,26 +8,25 @@
 #ifndef PLUGIN_HPP
 #define PLUGIN_HPP
 
+#include "AppInfos.hpp"
+#include "Dock.hpp"
+#include "Settings.hpp"
+#include "SettingsDialog.hpp"
+#include "Theme.hpp"
+
 #include <gtk/gtk.h>
-#include <libwnck/libwnck.h>
+#include <libxfce4windowing/libxfce4windowing.h>
 
 #include <iostream>
 #include <string>
 #include <vector>
 
-#include "AppInfos.hpp"
-#include "Dock.hpp"
-#include "Hotkeys.hpp"
-#include "Settings.hpp"
-#include "SettingsDialog.hpp"
-#include "Theme.hpp"
-
 extern "C"
 {
 #include <libxfce4panel/libxfce4panel.h>
 #include <libxfce4ui/libxfce4ui.h>
 #include <libxfce4util/libxfce4util.h>
-void construct(XfcePanelPlugin* xfPlugin);
+	void construct(XfcePanelPlugin* xfPlugin);
 }
 
 #define HELP_WEBSITE "https://docs.xfce.org/panel-plugins/xfce4-docklike-plugin/start"
