@@ -6,6 +6,9 @@
  */
 
 #include "Settings.hpp"
+#ifdef ENABLE_X11
+#include "Hotkeys.hpp"
+#endif
 
 namespace Settings
 {
@@ -63,10 +66,11 @@ namespace Settings
 				g_key_file_set_boolean(mFile.get(), "user", "showPreviews", _showPreviews);
 				saveFile();
 
-				Dock::mGroups.forEach([](std::pair<std::shared_ptr<AppInfo>, std::shared_ptr<Group>> g) -> void
-					{ g.second->mGroupMenu.showPreviewsChanged(); });
+				Dock::mGroups.forEach([](std::pair<std::shared_ptr<AppInfo>, std::shared_ptr<Group>> g) -> void {
+					g.second->mGroupMenu.showPreviewsChanged();
+				});
 			});
-		
+
 		showWindowCount.setup(g_key_file_get_boolean(file, "user", "showWindowCount", nullptr),
 			[](bool _showWindowCount) -> void {
 				g_key_file_set_boolean(mFile.get(), "user", "showWindowCount", _showWindowCount);
@@ -195,7 +199,10 @@ namespace Settings
 				g_key_file_set_boolean(mFile.get(), "user", "keyComboActive", _keyComboActive);
 				saveFile();
 
-				Hotkeys::updateSettings();
+#ifdef ENABLE_X11
+				if (GDK_IS_X11_DISPLAY(gdk_display_get_default()))
+					Hotkeys::updateSettings();
+#endif
 			});
 
 		keyAloneActive.setup(g_key_file_get_boolean(file, "user", "keyAloneActive", nullptr),
@@ -203,7 +210,10 @@ namespace Settings
 				g_key_file_set_boolean(mFile.get(), "user", "keyAloneActive", _keyAloneActive);
 				saveFile();
 
-				Hotkeys::updateSettings();
+#ifdef ENABLE_X11
+				if (GDK_IS_X11_DISPLAY(gdk_display_get_default()))
+					Hotkeys::updateSettings();
+#endif
 			});
 
 		gchar** pinnedListBuffer = g_key_file_get_string_list(file, "user", "pinned", nullptr, nullptr);
@@ -237,13 +247,13 @@ namespace Settings
 				g_key_file_set_integer(mFile.get(), "user", "dockSize", _dockSize);
 				saveFile();
 			});
-		
+
 		previewScale.setup(g_key_file_get_double(file, "user", "previewScale", nullptr),
 			[](int _previewScale) -> void {
 				g_key_file_set_double(mFile.get(), "user", "previewScale", _previewScale);
 				saveFile();
 			});
-		
+
 		previewSleep.setup(g_key_file_get_integer(file, "user", "previewSleep", nullptr),
 			[](int _previewSleep) -> void {
 				g_key_file_set_integer(mFile.get(), "user", "previewSleep", _previewSleep);
